import aiinterface.AIInterface;
import aiinterface.CommandCenter;
import enumerate.Action;
import struct.CharacterData;
import struct.FrameData;
import struct.GameData;
import struct.Key;

public class SimpleAI implements AIInterface {

	//--grey-bg --mute --inverted-player 1 -n 50 --c1 ZEN --c2 ZEN --a1 SimpleReinforcement --a2 MCTS --disable-window --fastmode
	private boolean _playerid;
	private CommandCenter _cmd;
	private Key _key;
	private FrameData _framedata;
	private CharacterData _player;
	private CharacterData _enemy;
	private SimpleTraining _training;
	
	@Override
	public int initialize(GameData gameData, boolean playerID) {
		_playerid = playerID;
		_cmd = new CommandCenter();
		_key = new Key();
		_training = new SimpleTraining(gameData, playerID, true);
		System.out.println("round start");
		return 0;
	}
	
	@Override
	public void close() {
	}

	@Override
	public void getInformation(FrameData frameData) {
		_framedata = frameData;
		_cmd.setFrameData(_framedata, _playerid);
		_player = _framedata.getCharacter(_playerid);
		_enemy = _framedata.getCharacter(!_playerid);
	}

	@Override
	public Key input() {
		return _key;
	}

	@Override
	public void processing() {			
		if(!canProcess())
			return;

		_training.update(_player, _enemy, _framedata);
		if (_cmd.getSkillFlag()) {
			_key = _cmd.getSkillKey();
		} else{
			_key.empty();
			_cmd.skillCancel();
			Action selectedact = _training.selectAction(_player, _enemy, _framedata);
			_cmd.commandCall(selectedact.name());
		}
	}

	@Override
	public void roundEnd(int p1Hp, int p2Hp, int frames) {
		_training.endRound(_player.getHp() > _enemy.getHp());
		System.out.println("iswin: " + (_player.getHp() > _enemy.getHp()) + " || HP1:" + p1Hp + " || HP2:" +p2Hp);
	}
	
	public boolean canProcess() {
		return !_framedata.getEmptyFlag() && _framedata.getRemainingFramesNumber() > 0;
	}
}
